@@ -25,10 +25,8 @@
 #include <sys/stat.h>
 
 #include <glib.h>
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/account.h>
-#include <telepathy-glib/util.h>
-#include <telepathy-glib/svc-generic.h>
+#include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #include <telepathy-logger/event-internal.h>
 #include <telepathy-logger/text-event.h>
