@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2009 Collabora Ltd.
  *
@@ -27,7 +26,7 @@
 #include <string.h>
 
 #include <glib.h>
-#include <telepathy-glib/defs.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #ifdef ENABLE_DEBUG
 
