@@ -28,6 +28,7 @@
 
 #include <telepathy-glib/telepathy-glib.h>
 
+#include "log-iter-pidgin-internal.h"
 #include "log-store-internal.h"
 #include "log-store-pidgin-internal.h"
 #include "log-manager-internal.h"
@@ -38,6 +39,8 @@
 #define DEBUG_FLAG TPL_DEBUG_LOG_STORE
 #include "debug-internal.h"
 
+#define TPL_LOG_STORE_PIDGIN_NAME "Pidgin"
+
 #define TXT_LOG_FILENAME_SUFFIX ".txt"
 #define HTML_LOG_FILENAME_SUFFIX ".html"
 
@@ -46,16 +49,11 @@ struct _TplLogStorePidginPriv
   gboolean test_mode;
 
   gchar *basedir;
-  gchar *name;
-  gboolean readable;
-  gboolean writable;
 };
 
 enum {
     PROP_0,
-    PROP_NAME,
     PROP_READABLE,
-    PROP_WRITABLE,
     PROP_BASEDIR,
     PROP_TESTMODE,
 };
@@ -68,12 +66,9 @@ static void tpl_log_store_pidgin_get_property (GObject *object, guint param_id,
 static void tpl_log_store_pidgin_set_property (GObject *object, guint param_id, const GValue *value,
     GParamSpec *pspec);
 static const gchar *log_store_pidgin_get_name (TplLogStore *store);
-static void log_store_pidgin_set_name (TplLogStorePidgin *self, const gchar *data);
 static const gchar *log_store_pidgin_get_basedir (TplLogStorePidgin *self);
 static void log_store_pidgin_set_basedir (TplLogStorePidgin *self,
     const gchar *data);
-static void log_store_pidgin_set_writable (TplLogStorePidgin *self, gboolean data);
-static void log_store_pidgin_set_readable (TplLogStorePidgin *self, gboolean data);
 
 
 G_DEFINE_TYPE_WITH_CODE (TplLogStorePidgin, tpl_log_store_pidgin,
@@ -90,14 +85,8 @@ tpl_log_store_pidgin_get_property (GObject *object,
 
   switch (param_id)
     {
-      case PROP_NAME:
-        g_value_set_string (value, priv->name);
-        break;
-      case PROP_WRITABLE:
-        g_value_set_boolean (value, priv->writable);
-        break;
       case PROP_READABLE:
-        g_value_set_boolean (value, priv->readable);
+        g_value_set_boolean (value, TRUE);
         break;
       case PROP_BASEDIR:
         g_value_set_string (value, priv->basedir);
@@ -122,15 +111,6 @@ tpl_log_store_pidgin_set_property (GObject *object,
 
   switch (param_id)
     {
-      case PROP_NAME:
-        log_store_pidgin_set_name (self, g_value_get_string (value));
-        break;
-      case PROP_READABLE:
-        log_store_pidgin_set_readable (self, g_value_get_boolean (value));
-        break;
-      case PROP_WRITABLE:
-        log_store_pidgin_set_writable (self, g_value_get_boolean (value));
-        break;
       case PROP_BASEDIR:
         log_store_pidgin_set_basedir (self, g_value_get_string (value));
         break;
@@ -152,9 +132,6 @@ tpl_log_store_pidgin_dispose (GObject *self)
   g_free (priv->basedir);
   priv->basedir = NULL;
 
-  g_free (priv->name);
-  priv->name = NULL;
-
   G_OBJECT_CLASS (tpl_log_store_pidgin_parent_class)->dispose (self);
 }
 
@@ -169,9 +146,7 @@ tpl_log_store_pidgin_class_init (TplLogStorePidginClass *klass)
   object_class->set_property = tpl_log_store_pidgin_set_property;
   object_class->dispose = tpl_log_store_pidgin_dispose;
 
-  g_object_class_override_property (object_class, PROP_NAME, "name");
   g_object_class_override_property (object_class, PROP_READABLE, "readable");
-  g_object_class_override_property (object_class, PROP_WRITABLE, "writable");
 
   /**
    * TplLogStorePidgin:basedir:
@@ -212,7 +187,7 @@ log_store_pidgin_get_name (TplLogStore *store)
 
   g_return_val_if_fail (TPL_IS_LOG_STORE_PIDGIN (self), NULL);
 
-  return self->priv->name;
+  return TPL_LOG_STORE_PIDGIN_NAME;
 }
 
 
@@ -243,18 +218,6 @@ log_store_pidgin_get_basedir (TplLogStorePidgin *self)
 }
 
 
-static void
-log_store_pidgin_set_name (TplLogStorePidgin *self,
-    const gchar *data)
-{
-  g_return_if_fail (TPL_IS_LOG_STORE_PIDGIN (self));
-  g_return_if_fail (!TPL_STR_EMPTY (data));
-  g_return_if_fail (self->priv->name == NULL);
-
-  self->priv->name = g_strdup (data);
-}
-
-
 static void
 log_store_pidgin_set_basedir (TplLogStorePidgin *self,
     const gchar *data)
@@ -272,26 +235,6 @@ log_store_pidgin_set_basedir (TplLogStorePidgin *self,
 }
 
 
-static void
-log_store_pidgin_set_readable (TplLogStorePidgin *self,
-    gboolean data)
-{
-  g_return_if_fail (TPL_IS_LOG_STORE_PIDGIN (self));
-
-  self->priv->readable = data;
-}
-
-
-static void
-log_store_pidgin_set_writable (TplLogStorePidgin *self,
-    gboolean data)
-{
-  g_return_if_fail (TPL_IS_LOG_STORE_PIDGIN (self));
-
-  self->priv->writable = data;
-}
-
-
 /* internal: get the full name of the storing directory, including protocol
  * and id */
 static gchar *
@@ -1182,6 +1125,20 @@ log_store_pidgin_get_filtered_events (TplLogStore *self,
 }
 
 
+static TplLogIter *
+log_store_pidgin_create_iter (TplLogStore *store,
+    TpAccount *account,
+    TplEntity *target,
+    gint type_mask)
+{
+  g_return_val_if_fail (TPL_IS_LOG_STORE_PIDGIN (store), NULL);
+  g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
+  g_return_val_if_fail (TPL_IS_ENTITY (target), NULL);
+
+  return tpl_log_iter_pidgin_new (store, account, target, type_mask);
+}
+
+
 static void
 log_store_iface_init (gpointer g_iface,
     gpointer iface_data)
@@ -1196,4 +1153,5 @@ log_store_iface_init (gpointer g_iface,
   iface->get_entities = log_store_pidgin_get_entities;
   iface->search_new = log_store_pidgin_search_new;
   iface->get_filtered_events = log_store_pidgin_get_filtered_events;
+  iface->create_iter = log_store_pidgin_create_iter;
 }
