@@ -1370,10 +1370,11 @@ log_store_xml_get_events_for_file (TplLogStoreXml *self,
   ctxt = xmlNewParserCtxt ();
 
   /* Parse and validate the file. */
-  doc = xmlCtxtReadFile (ctxt, filename, NULL, 0);
+  doc = xmlCtxtReadFile (ctxt, filename, NULL, XML_PARSE_RECOVER);
   if (!doc)
     {
-      g_warning ("Failed to parse file:'%s'", filename);
+      if (!self->priv->test_mode)
+        g_warning ("Failed to parse file:'%s'", filename);
       xmlFreeParserCtxt (ctxt);
       g_free (self_id);
       return;
@@ -1443,6 +1444,7 @@ log_store_xml_get_events_for_file (TplLogStoreXml *self,
   DEBUG ("Parsed %u events", num_events);
 
   g_free (target_id);
+  g_free (self_id);
   xmlFreeDoc (doc);
   xmlFreeParserCtxt (ctxt);
   g_hash_table_unref (supersedes_links);
