@@ -26,13 +26,7 @@
  */
 
 #include <glib-object.h>
-#include <telepathy-glib/account.h>
-#include <telepathy-glib/channel.h>
-#include <telepathy-glib/connection.h>
-#include <telepathy-glib/contact.h>
-#include <telepathy-glib/text-channel.h>
-
-#include "channel-internal.h"
+#include <telepathy-glib/telepathy-glib.h>
 
 G_BEGIN_DECLS
 
@@ -54,6 +48,10 @@ typedef enum
   TPL_TEXT_CHANNEL_ERROR_NEED_MESSAGE_INTERFACE,
 } TplTextChannelError;
 
+#define TPL_TEXT_CHANNEL_FEATURE_CORE \
+  _tpl_text_channel_get_feature_quark_core ()
+GQuark _tpl_text_channel_get_feature_quark_core (void) G_GNUC_CONST;
+
 typedef struct _TplTextChannelPriv TplTextChannelPriv;
 typedef struct
 {
@@ -71,7 +69,15 @@ typedef struct
 GType _tpl_text_channel_get_type (void);
 
 TplTextChannel * _tpl_text_channel_new (TpConnection *conn,
-    const gchar *object_path, GHashTable *tp_chan_props, TpAccount *account,
+    const gchar *object_path,
+    GHashTable *tp_chan_props,
+    GError **error);
+
+TplTextChannel * _tpl_text_channel_new_with_factory (
+    TpSimpleClientFactory *factory,
+    TpConnection *conn,
+    const gchar *object_path,
+    const GHashTable *tp_chan_props,
     GError **error);
 
 G_END_DECLS
