@@ -23,12 +23,9 @@
 #include "text-channel-internal.h"
 
 #include <glib.h>
-#include <telepathy-glib/contact.h>
-#include <telepathy-glib/enums.h>
-#include <telepathy-glib/proxy.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "action-chain-internal.h"
-#include "channel-internal.h"
 #include "entity-internal.h"
 #include "event-internal.h"
 #include "log-manager-internal.h"
@@ -49,205 +46,34 @@ struct _TplTextChannelPriv
   TplEntity *remote;
 };
 
-static TpContactFeature features[3] = {
-  TP_CONTACT_FEATURE_ALIAS,
-  TP_CONTACT_FEATURE_PRESENCE,
-  TP_CONTACT_FEATURE_AVATAR_TOKEN
-};
-
-static void tpl_text_channel_iface_init (TplChannelInterface *iface);
-
-G_DEFINE_TYPE_WITH_CODE (TplTextChannel, _tpl_text_channel,
-    TP_TYPE_TEXT_CHANNEL,
-    G_IMPLEMENT_INTERFACE (TPL_TYPE_CHANNEL, tpl_text_channel_iface_init))
+G_DEFINE_TYPE (TplTextChannel, _tpl_text_channel, TP_TYPE_TEXT_CHANNEL)
 
 
 static void
-connection_prepared_cb (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data)
+get_my_contact (TplTextChannel *self)
 {
-  TplActionChain *ctx = user_data;
-  GError *error = NULL;
-
-  if (!tp_proxy_prepare_finish (source, result, &error))
-    {
-      _tpl_action_chain_terminate (ctx, error);
-      g_error_free (error);
-      return;
-    }
-
-  _tpl_action_chain_continue (ctx);
-}
-
-
-static void
-pendingproc_prepare_tp_connection (TplActionChain *ctx,
-    gpointer user_data)
-{
-  TplChannel *chan = _tpl_action_chain_get_object (ctx);
-  TpConnection *conn = tp_channel_borrow_connection (TP_CHANNEL (chan));
-  GQuark conn_features[] = { TP_CONNECTION_FEATURE_CORE, 0 };
-
-  tp_proxy_prepare_async (conn, conn_features, connection_prepared_cb, ctx);
-}
-
-
-static void
-channel_prepared_cb (GObject *source,
-    GAsyncResult *result,
-    gpointer ctx)
-{
-  TplChannel *chan = _tpl_action_chain_get_object (ctx);
-  GError *error = NULL;
-
-  if (!tp_proxy_prepare_finish (source, result, &error))
-    {
-      _tpl_action_chain_terminate (ctx, error);
-      g_error_free (error);
-      return;
-    }
-  else if (!tp_proxy_has_interface_by_id (TP_PROXY (chan),
-        TP_IFACE_QUARK_CHANNEL_INTERFACE_MESSAGES))
-    {
-      error = g_error_new (TPL_TEXT_CHANNEL_ERROR,
-          TPL_TEXT_CHANNEL_ERROR_NEED_MESSAGE_INTERFACE,
-          "The text channel does not implement Message interface.");
-      _tpl_action_chain_terminate (ctx, error);
-      g_error_free (error);
-      return;
-    }
-
-  _tpl_action_chain_continue (ctx);
-}
-
-
-static void
-pendingproc_prepare_tp_text_channel (TplActionChain *ctx,
-    gpointer user_data)
-{
-  TplChannel *chan = _tpl_action_chain_get_object (ctx);
-  GQuark chan_features[] = {
-      TP_CHANNEL_FEATURE_CORE,
-      TP_CHANNEL_FEATURE_GROUP,
-      TP_TEXT_CHANNEL_FEATURE_INCOMING_MESSAGES,
-      0
-  };
-
-  tp_proxy_prepare_async (chan, chan_features, channel_prepared_cb, ctx);
-}
-
-
-static void
-get_self_contact_cb (TpConnection *connection,
-    guint n_contacts,
-    TpContact *const *contacts,
-    guint n_failed,
-    const TpHandle *failed,
-    const GError *error,
-    gpointer user_data,
-    GObject *weak_object)
-{
-  TplActionChain *ctx = user_data;
-  TplTextChannel *tpl_text = _tpl_action_chain_get_object (ctx);
-  TplChannel *tpl_chan = TPL_CHANNEL (tpl_text);
-  TpChannel *tp_chan = TP_CHANNEL (tpl_chan);
-
-  g_return_if_fail (TPL_IS_TEXT_CHANNEL (tpl_text));
-
-  if (n_failed > 0)
-    {
-      TpConnection *tp_conn = tp_channel_borrow_connection (tp_chan);
-      const gchar *conn_path;
-      GError *new_error = NULL;
-
-      conn_path = tp_proxy_get_object_path (TP_PROXY (tp_conn));
-
-      new_error = g_error_new (error->domain, error->code,
-          "Error resolving self handle for connection %s: %s)",
-          conn_path, error->message);
-
-      _tpl_action_chain_terminate (ctx, new_error);
-      g_error_free (new_error);
-      return;
-    }
-
-  tpl_text->priv->self = tpl_entity_new_from_tp_contact (contacts[0],
-      TPL_ENTITY_SELF);
-
-  _tpl_action_chain_continue (ctx);
-}
-
-
-static void
-pendingproc_get_my_contact (TplActionChain *ctx,
-    gpointer user_data)
-{
-  TplTextChannel *tpl_text = _tpl_action_chain_get_object (ctx);
-  TpChannel *chan = TP_CHANNEL (tpl_text);
-  TpConnection *tp_conn = tp_channel_borrow_connection (chan);
-  TpHandle my_handle;
-
-  my_handle = tp_channel_group_get_self_handle (chan);
-  if (my_handle == 0)
-    my_handle = tp_connection_get_self_handle (tp_conn);
-
-  tp_connection_get_contacts_by_handle (tp_conn, 1, &my_handle,
-      G_N_ELEMENTS (features), features, get_self_contact_cb, ctx, NULL,
-      G_OBJECT (tpl_text));
-}
-
-
-static void
-get_remote_contact_cb (TpConnection *connection,
-    guint n_contacts,
-    TpContact *const *contacts,
-    guint n_failed,
-    const TpHandle *failed,
-    const GError *error,
-    gpointer user_data,
-    GObject *weak_object)
-{
-  TplActionChain *ctx = user_data;
-  TplTextChannel *self = TPL_TEXT_CHANNEL (weak_object);
-
-  if (error != NULL)
-    {
-      GError *new_error = NULL;
-      new_error = g_error_new (error->domain, error->code,
-          "Failed to get remote contact: %s", error->message);
-      _tpl_action_chain_terminate (ctx, new_error);
-      g_error_free (new_error);
-    }
-  else if (n_failed > 0)
-    {
-      GError *new_error = g_error_new (TPL_TEXT_CHANNEL_ERROR,
-          TPL_TEXT_CHANNEL_ERROR_FAILED,
-          "Failed to prepare remote contact.");
-      _tpl_action_chain_terminate (ctx, new_error);
-      g_error_free (new_error);
-    }
-  else
-    {
-      self->priv->remote =
-        tpl_entity_new_from_tp_contact (contacts[0], TPL_ENTITY_CONTACT);
-      _tpl_action_chain_continue (ctx);
-    }
-}
-
-
-static void
-pendingproc_get_remote_contact (TplActionChain *ctx,
-    gpointer user_data)
-{
-  TplTextChannel *self = _tpl_action_chain_get_object (ctx);
   TpChannel *chan = TP_CHANNEL (self);
-  TpHandle handle;
-  TpHandleType handle_type;
+  TpConnection *tp_conn = tp_channel_borrow_connection (chan);
+  TpContact *my_contact;
 
-  handle = tp_channel_get_handle (chan, &handle_type);
+  my_contact = tp_channel_group_get_self_contact (chan);
+  if (my_contact == 0)
+    my_contact = tp_connection_get_self_contact (tp_conn);
 
-  if (handle_type == TP_HANDLE_TYPE_ROOM)
+  self->priv->self = tpl_entity_new_from_tp_contact (my_contact,
+      TPL_ENTITY_SELF);
+}
+
+
+static void
+get_remote_contact (TplTextChannel *self)
+{
+  TpChannel *chan = TP_CHANNEL (self);
+  TpContact *contact;
+
+  contact = tp_channel_get_target_contact (chan);
+
+  if (contact == NULL)
     {
       self->priv->is_chatroom = TRUE;
       self->priv->remote =
@@ -255,26 +81,11 @@ pendingproc_get_remote_contact (TplActionChain *ctx,
 
       PATH_DEBUG (self, "Chatroom id: %s",
           tpl_entity_get_identifier (self->priv->remote));
-
-      _tpl_action_chain_continue (ctx);
     }
   else
     {
-      TpConnection *tp_conn = tp_channel_borrow_connection (chan);
-      GArray *arr;
-
-      /* Get the contact of the TargetHandle */
-      arr = g_array_sized_new (FALSE, FALSE, sizeof (TpHandle), 1);
-      handle = tp_channel_get_handle (chan, NULL);
-
-      g_array_append_val (arr, handle);
-
-      tp_connection_get_contacts_by_handle (tp_conn,
-          arr->len, (TpHandle *) arr->data,
-          G_N_ELEMENTS (features), features, get_remote_contact_cb, ctx, NULL,
-          G_OBJECT (self));
-
-      g_array_unref (arr);
+      self->priv->remote =
+        tpl_entity_new_from_tp_contact (contact, TPL_ENTITY_CONTACT);
     }
 }
 
@@ -286,16 +97,16 @@ on_channel_invalidated_cb (TpProxy *proxy,
     gchar *message,
     gpointer user_data)
 {
-  TplChannel *tpl_chan = TPL_CHANNEL (user_data);
+  TpChannel *chan = TP_CHANNEL (user_data);
   TplObserver *observer = _tpl_observer_dup (NULL);
 
   g_return_if_fail (observer);
 
-  PATH_DEBUG (tpl_chan, "%s #%d %s",
+  PATH_DEBUG (chan, "%s #%d %s",
       g_quark_to_string (domain), code, message);
 
-  if (!_tpl_observer_unregister_channel (observer, tpl_chan))
-    PATH_DEBUG (tpl_chan, "Channel couldn't be unregistered correctly (BUG?)");
+  if (!_tpl_observer_unregister_channel (observer, chan))
+    PATH_DEBUG (chan, "Channel couldn't be unregistered correctly (BUG?)");
 
   g_object_unref (observer);
 }
@@ -604,10 +415,8 @@ pending_message_compare_timestamp (TpSignalledMessage *m1,
 
 
 static void
-pendingproc_store_pending_messages (TplActionChain *ctx,
-    gpointer user_data)
+store_pending_messages (TplTextChannel *self)
 {
-  TplTextChannel *self = _tpl_action_chain_get_object (ctx);
   TplLogStore *cache;
   GError *error = NULL;
   GList *cached_messages;
@@ -727,16 +536,12 @@ pendingproc_store_pending_messages (TplActionChain *ctx,
     }
 
   g_object_unref (cache);
-  _tpl_action_chain_continue (ctx);
 }
 
 
 static void
-pendingproc_connect_message_signals (TplActionChain *ctx,
-    gpointer user_data)
+connect_message_signals (TplTextChannel *self)
 {
-  TplTextChannel *self = _tpl_action_chain_get_object (ctx);
-
   tp_g_signal_connect_object (self, "invalidated",
       G_CALLBACK (on_channel_invalidated_cb), self, 0);
 
@@ -748,38 +553,69 @@ pendingproc_connect_message_signals (TplActionChain *ctx,
 
   tp_g_signal_connect_object (self, "pending-message-removed",
       G_CALLBACK (on_pending_message_removed_cb), self, 0);
-
-  _tpl_action_chain_continue (ctx);
-}
-
-static gboolean
-tpl_text_channel_prepare_finish (TplChannel *chan,
-    GAsyncResult *result,
-    GError **error)
-{
-  return _tpl_action_chain_new_finish (G_OBJECT (chan), result, error);
 }
 
 
 static void
-tpl_text_channel_prepare_async (TplChannel *chan,
-    GAsyncReadyCallback cb,
+_tpl_text_channel_prepare_core_async (TpProxy *proxy,
+    const TpProxyFeature *feature,
+    GAsyncReadyCallback callback,
     gpointer user_data)
 {
-  TplActionChain *actions;
+  TplTextChannel *self = (TplTextChannel *) proxy;
 
-  actions = _tpl_action_chain_new_async (G_OBJECT (chan), cb, user_data);
-  _tpl_action_chain_append (actions, pendingproc_prepare_tp_connection, NULL);
-  _tpl_action_chain_append (actions, pendingproc_prepare_tp_text_channel, NULL);
-  _tpl_action_chain_append (actions, pendingproc_get_my_contact, NULL);
-  _tpl_action_chain_append (actions, pendingproc_get_remote_contact, NULL);
-  _tpl_action_chain_append (actions, pendingproc_store_pending_messages, NULL);
-  _tpl_action_chain_append (actions, pendingproc_connect_message_signals, NULL);
+  if (!tp_proxy_has_interface_by_id (self,
+          TP_IFACE_QUARK_CHANNEL_INTERFACE_MESSAGES))
+    {
+      g_simple_async_report_error_in_idle ((GObject *) self,
+          callback, user_data, TPL_TEXT_CHANNEL_ERROR,
+          TPL_TEXT_CHANNEL_ERROR_NEED_MESSAGE_INTERFACE,
+          "The text channel does not implement Message interface.");
+      return;
+    }
 
-  _tpl_action_chain_continue (actions);
+  get_my_contact (self);
+  get_remote_contact (self);
+  store_pending_messages (self);
+  connect_message_signals (self);
+
+  tp_simple_async_report_success_in_idle ((GObject *) self, callback, user_data,
+      _tpl_text_channel_prepare_core_async);
 }
 
 
+GQuark
+_tpl_text_channel_get_feature_quark_core (void)
+{
+  return g_quark_from_static_string ("tpl-text-channel-feature-core");
+}
+
+enum {
+    FEAT_CORE,
+    N_FEAT
+};
+
+static const TpProxyFeature *
+tpl_text_channel_list_features (TpProxyClass *cls G_GNUC_UNUSED)
+{
+  static TpProxyFeature features[N_FEAT + 1] = { { 0 } };
+  static GQuark depends_on[3] = { 0, 0, 0 };
+
+  if (G_LIKELY (features[0].name != 0))
+    return features;
+
+  features[FEAT_CORE].name = TPL_TEXT_CHANNEL_FEATURE_CORE;
+  features[FEAT_CORE].prepare_async = _tpl_text_channel_prepare_core_async;
+  depends_on[0] = TP_TEXT_CHANNEL_FEATURE_INCOMING_MESSAGES;
+  depends_on[1] = TP_CHANNEL_FEATURE_CONTACTS;
+  features[FEAT_CORE].depends_on = depends_on;
+
+  /* assert that the terminator at the end is there */
+  g_assert (features[N_FEAT].name == 0);
+
+  return features;
+}
+
 static void
 tpl_text_channel_dispose (GObject *obj)
 {
@@ -805,22 +641,17 @@ static void
 _tpl_text_channel_class_init (TplTextChannelClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  TpProxyClass *proxy_class = (TpProxyClass *) klass;
 
   object_class->dispose = tpl_text_channel_dispose;
   object_class->finalize = tpl_text_channel_finalize;
 
+  proxy_class->list_features = tpl_text_channel_list_features;
+
   g_type_class_add_private (object_class, sizeof (TplTextChannelPriv));
 }
 
 
-static void
-tpl_text_channel_iface_init (TplChannelInterface *iface)
-{
-  iface->prepare_async = tpl_text_channel_prepare_async;
-  iface->prepare_finish = tpl_text_channel_prepare_finish;
-}
-
-
 static void
 _tpl_text_channel_init (TplTextChannel *self)
 {
@@ -832,12 +663,11 @@ _tpl_text_channel_init (TplTextChannel *self)
 
 
 /**
- * _tpl_text_channel_new
+ * _tpl_text_channel_new:
  * @conn: TpConnection instance owning the channel
  * @object_path: the channel's DBus path
  * @tp_chan_props: channel's immutable properties, obtained for example by
  * %tp_channel_borrow_immutable_properties()
- * @account: TpAccount instance, related to the new #TplTextChannel
  * @error: location of the GError, used in case a problem is raised while
  * creating the channel
  *
@@ -860,7 +690,17 @@ TplTextChannel *
 _tpl_text_channel_new (TpConnection *conn,
     const gchar *object_path,
     GHashTable *tp_chan_props,
-    TpAccount *account,
+    GError **error)
+{
+  return _tpl_text_channel_new_with_factory (NULL, conn, object_path,
+      tp_chan_props, error);
+}
+
+TplTextChannel *
+_tpl_text_channel_new_with_factory (TpSimpleClientFactory *factory,
+    TpConnection *conn,
+    const gchar *object_path,
+    const GHashTable *tp_chan_props,
     GError **error)
 {
   TpProxy *conn_proxy = TP_PROXY (conn);
@@ -869,7 +709,6 @@ _tpl_text_channel_new (TpConnection *conn,
   /* Do what tpl_channel_new does + set TplTextChannel specific */
 
   g_return_val_if_fail (TP_IS_CONNECTION (conn), NULL);
-  g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
   g_return_val_if_fail (!TPL_STR_EMPTY (object_path), NULL);
   g_return_val_if_fail (tp_chan_props != NULL, NULL);
 
@@ -878,6 +717,7 @@ _tpl_text_channel_new (TpConnection *conn,
 
   self = g_object_new (TPL_TYPE_TEXT_CHANNEL,
       /* TpChannel properties */
+      "factory", factory,
       "connection", conn,
       "dbus-daemon", conn_proxy->dbus_daemon,
       "bus-name", conn_proxy->bus_name,
@@ -886,7 +726,7 @@ _tpl_text_channel_new (TpConnection *conn,
       "channel-properties", tp_chan_props,
       NULL);
 
-  self->priv->account = g_object_ref (account);
+  self->priv->account = g_object_ref (tp_connection_get_account (conn));
 
   return self;
 }
